#!/usr/bin/perl
# Use command 'perl ingcrtrsp.pl' to get help.
#
# IBM System Automation for OS/390
# ingcrtrsp.pl Version 02.01.01
# 01 March 2002

if ( @ARGV [0] eq "" || @ARGV [1] eq "" )
{
  &provideHelpAndDie () ;
}


# Set trace level.
if ( @ARGV [2] eq "" )
{
  $TraceLvl = 1 ;
}
else
{
  if ( @ARGV [2] eq "0" || @ARGV [2] eq "1" || @ARGV [2] eq "2" ||
       @ARGV [2] eq "3" || @ARGV [2] eq "4" || @ARGV [2] eq "5" ||
       @ARGV [2] eq "6" || @ARGV [2] eq "7" || @ARGV [2] eq "8" ||
       @ARGV [2] eq "9" || @ARGV [2] eq "10" )
  {
    $TraceLvl = @ARGV [2] ;
  }
  else
  {
    $TraceLvl = 1 ;
  }
}


# Start of program.
# Trace
if ( $TraceLvl > 0 )
{
  print "Program ingcrtrsp started.\n" ;
  print "Trace level is: $TraceLvl\n" ;
  $timestamp = localtime ;
  print "Timestamp is: $timestamp\n" ;
}

# Read the file with the filenames.
@FilenameList = &readFileFromDisk (@ARGV [0]) ;
chop ( @FilenameList ) ;    # remove linefeed.


# Open output file.
$outputFileName = @ARGV [1] ;
# Trace
if ( $TraceLvl > 0 )
{
  print "Output file is: '$outputFileName'\n" ;
}
open ( outFileHandle, ">" . $outputFileName ) ||
          die ("ERROR: cannot open file '$outputFileName' for writing.\n") ;



# Iterate through the list of filenames: Read the content of each
# file and append it to the output file.
# The output file will contain a concatenation of all input files.
$totalLinesWritten = 0 ;
$fileNo = 1 ;
foreach $Filename (@FilenameList)
{
  # Trace
  if ( $TraceLvl > 0 )
  {
    print "Reading file $fileNo: '$Filename'\n" ;
  }
  # Read ONE file.
  @InputFileList = &readFileFromDisk ( $Filename ) ;
  $fileNo++ ;

  $lineNo = 1 ;
  # Write the lines to the output file.
  foreach $Line (@InputFileList)
  {
    # Trace
    if ( $TraceLvl > 7 )
    {
      print "Writing line $lineNo: $Line" ;
    }
    print outFileHandle "$Line" ;
    $lineNo++ ;
    $totalLinesWritten++ ;
  }
}

# Trace
if ( $TraceLvl > 0 )
{
  print "Total number of lines written to output file: $totalLinesWritten\n" ;
}


# close output file.
close ( outFileHandle ) ;


# End of program.
# Trace
if ( $TraceLvl > 0 )
{
  print "Program ingcrtrsp finished.\n" ;
}


# subroutines ----------------------------------------------


#read a text file from disk
sub readFileFromDisk
{
  open ( FH, @_[0] ) || die ("ERROR: cannot read file @_[0].\n" ) ;
  local ( @records ) = <FH> ;
  close (FH) ;
  return ( @records ) ;
}


#print some hints on the screen
sub provideHelpAndDie
{
  print 'usage:  ingcrtrsp.pl listOfFiles.txt cpein.rsp [traceLevel]' ;
  print "\n\nlistOfFiles.txt input; A filename. The file contains a " .
        "list of filenames.\n" .
        "cpein.rsp      output; 'cpebatch cpein.rsp -I -G' will load " .
        "the NMC topology\n" .
        "                       server database with the definitions from " .
        "the response\n" .
        "                       file 'cpein.rsp'.\n" .
        "traceLevel      input; A number from 0 (no trace) to 10\n\n" ;
  print "This program creates a file 'cpein.rsp' from all input files " .
        "mentioned in a\nlist. The list itself is a file identified by " .
        "the filename 'listOfFiles.txt'.\n" .
        "'cpein.rsp' can be used to create definitions in the NMC " .
        "topology server\ndatabase.\n" .
        "The names 'listOfFiles.txt' and 'cpein.rsp' can be replaced by\n" .
        "any other filenames.\n" ;
  print "Modify the list of files to match your installation. " .
        "Note: The sequence\n" .
        "is important: manager, command, " .
        "commandset, profile, operator.\n" ;
  die "try again.\n" ;
}
