#!/usr/bin/perl
# Use command 'perl ingwipe.pl' to get help.
#
# IBM System Automation for OS/390
# ingwipe.pl Version 02.01.01
# 01 March 2002

if ( @ARGV [0] eq "" || @ARGV [1] eq "" )
{
  &provideHelpAndDie () ;
}

# Set trace level.
if ( @ARGV [2] eq "" )
{
  $TraceLvl = 1 ;
}
else
{
  if ( @ARGV [2] eq "0" || @ARGV [2] eq "1" || @ARGV [2] eq "2" ||
       @ARGV [2] eq "3" || @ARGV [2] eq "4" || @ARGV [2] eq "5" ||
       @ARGV [2] eq "6" || @ARGV [2] eq "7" || @ARGV [2] eq "8" ||
       @ARGV [2] eq "9" || @ARGV [2] eq "10" )
  {
    $TraceLvl = @ARGV [2] ;
  }
  else
  {
    $TraceLvl = 1 ;
  }
}


# Start of program.
# Trace
if ( $TraceLvl > 0 )
{
  print "Program ingwipe started.\n" ;
  print "Trace level is: $TraceLvl\n" ;
  $timestamp = localtime ;
  print "Timestamp is: $timestamp\n" ;
}

# Read the input file which is a NMC topology server dump.
@CpeOutList = &readFileFromDisk (@ARGV [0]) ;

# Search for keywords (MANAGER, COMMAND, COMMAND_SET, PROFILE, OPERATOR)
# in the input file. Keywords must start at the first column.
# If a keyword is found then store the index of the line into an array.
$idx = 0 ;
$lineIdx = 0 ;
foreach $CpeOutLine (@CpeOutList)
{
  $found = 0 ;

  if ( $CpeOutLine =~ /^MANAGER / )
  {
    $found = 1 ;
    # Trace
    if ( $TraceLvl > 1 )
    {
      print "Keyword MANAGER found at line index: $lineIdx\n" ;
    }
  }

  if ( $CpeOutLine =~ /^COMMAND / )
  {
    $found = 1 ;
    # Trace
    if ( $TraceLvl > 1 )
    {
      print "Keyword COMMAND found at line index: $lineIdx\n" ;
    }
  }

  if ( $CpeOutLine =~ /^COMMAND_SET / )
  {
    $found = 1 ;
    # Trace
    if ( $TraceLvl > 1 )
    {
      print "Keyword COMMAND_SET found at line index: $lineIdx\n" ;
    }
  }

  if ( $CpeOutLine =~ /^PROFILE / )
  {
    $found = 1 ;
    # Trace
    if ( $TraceLvl > 1 )
    {
      print "Keyword PROFILE found at line index: $lineIdx\n" ;
    }
  }

  if ( $CpeOutLine =~ /^OPERATOR / )
  {
    $found = 1 ;
    # Trace
    if ( $TraceLvl > 1 )
    {
      print "Keyword OPERATOR found at line index: $lineIdx\n" ;
    }
  }


  if ( $found != 0 )
  {                  # A keyword was found.
    # Store the line index into an array.
    @itemsFound [$idx++] = $lineIdx ;
  }

  $lineIdx++ ;
}

# Trace
if ( $TraceLvl > 0 )
{
  print "Total number of lines searched for keywords: $lineIdx\n" ;
}




# Pick each index from the array. With the index take the line with the
# keyword from the input file. Write the line to the output file. Add the
# next line from the input file to the output file (this is the 'NAME'
# statement).
# Then append the 'DELETE' and ')' statements.
# In this way for each command block from the input file a delete-command
# block in the output file is created.
#
# Process the array in reverse order to delete OPERATORs first, then
# PROFILEs, then COMMAND_SETs,...


# Example for a input file:
#      COMMAND = (
#           NAME = INGVOTE - Pending Requests
#           COMMENT =
#           ...
#      )
# In the output file above statements will be translated to:
#      COMMAND = (
#           NAME = INGVOTE - Pending Requests
#           DELETE
#      )


# $#itemsFound returns the number of entries in the array minus one:
#   It returns the maximum index possible for the array.

$idxWipeList = 0 ;
for ( $idxItemsFound = $#itemsFound ; $idxItemsFound >= 0 ; $idxItemsFound-- )
{
  # Copy the line with the keyword from input to output file.
  $idxCpeOutList = @itemsFound [ $idxItemsFound ] ;
  $CpeOutLine = @CpeOutList [ $idxCpeOutList ] ;
  @WipeList [$idxWipeList++] = $CpeOutLine ;

  # Copy the line following the line with the keyword from the
  # input file to the output file. This line contains the 'NAME' statement.
  $idxCpeOutList++ ;
  $CpeOutLine = @CpeOutList [ $idxCpeOutList ] ;
  @WipeList [$idxWipeList++] = $CpeOutLine ;

  # Add the 'DELETE' statement.
  @WipeList [$idxWipeList++] = "     DELETE\n" ;

  # Add the ')' statement to end the block.
  @WipeList [$idxWipeList++] = ")\n" ;
}


# Write the output file to disk.
$outputFileName = @ARGV [1] ;
# Trace
if ( $TraceLvl > 0 )
{
  print "writing file: '$outputFileName'\n" ;
}
open ( filehandle, ">" . $outputFileName ) ||
          die ("ERROR: cannot open file '$outputFileName' for writing.\n") ;

print filehandle "* IBM System Automation for OS/390 NetView " .
      "Management Console Exploitation\n" .
      "*\n" .
      "* Use this file to wipeout the NMC topology server " .
      "database with command:\n" .
      "*     'cpebatch filename.rsp -I -M'\n" .
      "*\n" ;

foreach $Line (@WipeList)
{
  print filehandle "$Line" ;
  $idx++ ;
}
close ( filehandle ) ;


# End of program.
# Trace
if ( $TraceLvl > 0 )
{
  print "Program ingwipe finished.\n" ;
}


# subroutines ----------------------------------------------


#read a text file from disk
sub readFileFromDisk
{
  open ( FH, @_[0] ) || die ("ERROR: cannot read file @_[0].\n" ) ;
  local ( @records ) = <FH> ;
  close (FH) ;
  return ( @records ) ;
}


#print some hints on the screen
sub provideHelpAndDie
{
  print 'usage:  ingwipe.pl cpeout.rsp wipeout.rsp [traceLevel]' ;
  print "\n\ncpeout.rsp    input; file created " .
        "by 'cpebatch cpeout.rsp -O'\n" .
        "wipeout.rsp  output; 'cpebatch wipeout.rsp -I -M' will wipeout \n" .
        "                     the NMC topology server database.\n" .
        "traceLevel    input; A number from 0 (no trace) to 10\n\n" ;
  print "This program creates a file 'wipeout.rsp' from a input file " .
        "'cpeout.rsp'.\n" .
        "'wipeout.rsp' can be used to clean the " .
        "NMC topology server database.\n" ;
  die "\ntry again.\n" ;
}
